@@ -11,15 +11,15 @@ import (
 )
 
 const (
-	configKey       = "CONFIG"
-	configSourceKey = "CONFIG_SOURCE"
+	configKey = "CONFIG"
+	SourceKey = "CONFIG_SOURCE"
 )
 
 func (cfg *Config) Store() {
 	defer log.Trace(time.Now())
 
-	cache.Set(cache.Session, configSourceKey, cfg.Source, cache.INFINITE)
-	cache.Set(cache.Session, configKey, cfg, cache.INFINITE)
+	cache.Set(cache.Session, SourceKey, cfg.Source, cache.INFINITE)
+	cache.Set(cache.Session, configKey, cfg.Base64(), cache.INFINITE)
 }
 
 func Get(configFile string, reload bool) *Config {
@@ -27,18 +27,26 @@ func Get(configFile string, reload bool) *Config {
 
 	if reload {
 		log.Debug("reload mode enabled")
-		if source, OK := cache.Get[string](cache.Session, configSourceKey); OK {
-			return Load(source, false)
+		if source, OK := cache.Get[string](cache.Session, SourceKey); OK {
+			cfg := Load(source, false)
+			cfg.Store()
+			return cfg
 		}
 	}
 
-	cfg, found := cache.Get[*Config](cache.Session, configKey)
+	base64String, found := cache.Get[string](cache.Session, configKey)
 	if !found {
 		log.Debug("no cached config found")
 		return Load(configFile, false)
 	}
 
-	return cfg
+	var cfg Config
+	if err := cfg.Restore(base64String); err != nil {
+		log.Debug("failed to restore config from cache")
+		return Load(configFile, false)
+	}
+
+	return &cfg
 }
 
 func (cfg *Config) Base64() string {
@@ -54,3 +62,24 @@ func (cfg *Config) Base64() string {
 
 	return base64.StdEncoding.EncodeToString(buffer.Bytes())
 }
+
+func (cfg *Config) Restore(base64String string) error {
+	defer log.Trace(time.Now())
+
+	data, err := base64.StdEncoding.DecodeString(base64String)
+	if err != nil {
+		log.Error(err)
+		return err
+	}
+
+	var buffer bytes.Buffer
+	buffer.Write(data)
+	decoder := gob.NewDecoder(&buffer)
+	err = decoder.Decode(cfg)
+	if err != nil {
+		log.Error(err)
+		return err
+	}
+
+	return nil
+}
