@@ -5,7 +5,6 @@ import (
 	"io"
 	"net/http"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
@@ -18,7 +17,6 @@ type Request struct {
 
 type Environment interface {
 	HTTPRequest(url string, body io.Reader, timeout int, requestModifiers ...RequestModifier) ([]byte, error)
-	Cache() cache.Cache
 }
 
 func Do[a any](r *Request, url string, body io.Reader, requestModifiers ...RequestModifier) (a, error) {
