@@ -7,12 +7,14 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
+	"sync"
 	"testing"
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
+	"gopkg.in/ini.v1"
 
 	"github.com/stretchr/testify/assert"
 	testify_ "github.com/stretchr/testify/mock"
@@ -174,7 +176,6 @@ func TestEnabledInBareRepo(t *testing.T) {
 		bare = %s`, strconv.FormatBool(tc.IsBare))
 
 		env.On("HasParentFilePath", ".git", true).Return(&runtime.FileInfo{IsDir: true, Path: path}, nil)
-		env.On("FileContent", "git/config").Return(configData)
 		env.On("FileContent", "git/HEAD").Return(tc.HEAD)
 
 		props := properties.Map{
@@ -184,6 +185,11 @@ func TestEnabledInBareRepo(t *testing.T) {
 		g := &Git{}
 		g.Init(props, env)
 
+		g.configOnce = sync.Once{}
+		g.configOnce.Do(func() {
+			g.config, g.configErr = ini.Load([]byte(configData))
+		})
+
 		_ = g.Enabled()
 
 		assert.Equal(t, tc.IsBare, g.IsBare, tc.Case)
@@ -363,7 +369,7 @@ func TestSetGitHEADContextClean(t *testing.T) {
 		}
 		g.Init(props, env)
 
-		g.setGitHEADContext()
+		g.setHEADStatus()
 		assert.Equal(t, tc.Expected, g.HEAD, tc.Case)
 	}
 }
@@ -585,7 +591,7 @@ func TestSetGitStatus(t *testing.T) {
 		g.Merge = tc.Merge
 		tc.ExpectedStaging.Formats = map[string]string{}
 		tc.ExpectedWorking.Formats = map[string]string{}
-		g.setGitStatus()
+		g.setStatus()
 		assert.Equal(t, tc.ExpectedStaging, g.Staging, tc.Case)
 		assert.Equal(t, tc.ExpectedWorking, g.Working, tc.Case)
 		assert.Equal(t, tc.ExpectedHash, g.ShortHash, tc.Case)
@@ -674,7 +680,7 @@ func TestGitUpstream(t *testing.T) {
 		env := &mock.Environment{}
 		env.On("IsWsl").Return(false)
 		env.On("RunCommand", "git", []string{"-C", "", "--no-optional-locks", "-c", "core.quotepath=false",
-			"-c", "color.status=false", "remote", "get-url", "origin"}).Return(tc.Upstream, nil)
+			"-c", "color.status=false", "remote", "get-url", origin}).Return(tc.Upstream, nil)
 		env.On("GOOS").Return("unix")
 		props := properties.Map{
 			GithubIcon:      "GH",
@@ -698,6 +704,11 @@ func TestGitUpstream(t *testing.T) {
 		}
 		g.Init(props, env)
 
+		g.configOnce = sync.Once{}
+		g.configOnce.Do(func() {
+			g.configErr = errors.New("no config")
+		})
+
 		upstreamIcon := g.getUpstreamIcon()
 		assert.Equal(t, tc.Expected, upstreamIcon, tc.Case)
 	}
@@ -1107,13 +1118,15 @@ func TestGitCommit(t *testing.T) {
 
 func TestGitRemotes(t *testing.T) {
 	cases := []struct {
-		Case     string
-		Config   string
-		Expected int
+		ExpectedRemotes map[string]string
+		Case            string
+		Config          string
+		Expected        int
 	}{
 		{
-			Case:     "Empty config file",
-			Expected: 0,
+			Case:            "Empty config file",
+			Expected:        0,
+			ExpectedRemotes: map[string]string{},
 		},
 		{
 			Case:     "Two remotes",
@@ -1126,6 +1139,10 @@ func TestGitRemotes(t *testing.T) {
 	url = git@github.com:microsoft/test.git
 	fetch = +refs/heads/*:refs/remotes/upstream/*
 `,
+			ExpectedRemotes: map[string]string{
+				"origin":   "https://github.com/JanDeDobbeleer/test",
+				"upstream": "https://github.com/microsoft/test",
+			},
 		},
 		{
 			Case:     "One remote",
@@ -1135,17 +1152,40 @@ func TestGitRemotes(t *testing.T) {
 	url = git@github.com:JanDeDobbeleer/test.git
 	fetch = +refs/heads/*:refs/remotes/origin/*
 `,
+			ExpectedRemotes: map[string]string{
+				"origin": "https://github.com/JanDeDobbeleer/test",
+			},
 		},
 		{
-			Case:     "Broken config",
-			Expected: 0,
-			Config:   "{{}}",
+			Case:            "Broken config",
+			Expected:        0,
+			Config:          "{{}}",
+			ExpectedRemotes: map[string]string{},
+		},
+		{
+			Case:     "Three remotes with different URL formats",
+			Expected: 3,
+			Config: `
+[remote "origin"]
+	url = git@github.com:JanDeDobbeleer/test.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+[remote "upstream"]
+	url = https://github.com/microsoft/test.git
+	fetch = +refs/heads/*:refs/remotes/upstream/*
+[remote "fork"]
+	url = git@gitlab.com:user/test.git
+	fetch = +refs/heads/*:refs/remotes/fork/*
+`,
+			ExpectedRemotes: map[string]string{
+				"origin":   "https://github.com/JanDeDobbeleer/test",
+				"upstream": "https://github.com/microsoft/test.git",
+				"fork":     "https://gitlab.com/user/test",
+			},
 		},
 	}
 
 	for _, tc := range cases {
 		env := new(mock.Environment)
-		env.On("FileContent", "config").Return(tc.Config)
 
 		g := &Git{
 			Scm: Scm{
@@ -1154,8 +1194,20 @@ func TestGitRemotes(t *testing.T) {
 		}
 		g.Init(properties.Map{}, env)
 
+		g.configOnce = sync.Once{}
+		g.configOnce.Do(func() {
+			g.config, g.configErr = ini.Load([]byte(tc.Config))
+		})
+
 		got := g.Remotes()
 		assert.Equal(t, tc.Expected, len(got), tc.Case)
+
+		// Verify the actual remote names and URLs
+		for name, expectedURL := range tc.ExpectedRemotes {
+			actualURL, exists := got[name]
+			assert.True(t, exists, "%s: expected remote '%s' to exist", tc.Case, name)
+			assert.Equal(t, expectedURL, actualURL, "%s: remote '%s' URL mismatch", tc.Case, name)
+		}
 	}
 }
 
@@ -1282,3 +1334,97 @@ func TestDisableWithJJNoJJDirectory(t *testing.T) {
 
 	assert.True(t, g.Enabled()) // Should be enabled since .jj directory doesn't exist
 }
+
+func TestPushStatusAheadAndBehind(t *testing.T) {
+	cases := []struct {
+		Case               string
+		PushAheadCount     string
+		PushBehindCount    string
+		Config             string
+		ExpectedPushAhead  int
+		ExpectedPushBehind int
+	}{
+		{
+			Case:               "ahead and behind",
+			PushAheadCount:     "3",
+			PushBehindCount:    "5",
+			ExpectedPushAhead:  3,
+			ExpectedPushBehind: 5,
+		},
+		{
+			Case:               "only ahead",
+			PushAheadCount:     "2",
+			PushBehindCount:    "0",
+			ExpectedPushAhead:  2,
+			ExpectedPushBehind: 0,
+		},
+		{
+			Case:               "only behind",
+			PushAheadCount:     "0",
+			PushBehindCount:    "7",
+			ExpectedPushAhead:  0,
+			ExpectedPushBehind: 7,
+		},
+		{
+			Case:               "up to date",
+			PushAheadCount:     "0",
+			PushBehindCount:    "0",
+			ExpectedPushAhead:  0,
+			ExpectedPushBehind: 0,
+		},
+		{
+			Case:               "remote from config",
+			PushAheadCount:     "2",
+			PushBehindCount:    "0",
+			ExpectedPushAhead:  2,
+			ExpectedPushBehind: 0,
+			Config: `
+			[branch "main"]
+				remote = origin
+				merge = refs/heads/main
+			`,
+		},
+	}
+
+	for _, tc := range cases {
+		env := new(mock.Environment)
+		env.On("RunCommand", "git", []string{"-C", "/dir", "--no-optional-locks", "-c", "core.quotepath=false",
+			"-c", "color.status=false", "config", "--get", "remote.pushDefault"}).Return("", nil)
+		env.On("RunCommand", "git", []string{"-C", "/dir", "--no-optional-locks", "-c", "core.quotepath=false",
+			"-c", "color.status=false", "rev-list", "--count", "origin/main..HEAD"}).Return(tc.PushAheadCount, nil)
+		env.On("RunCommand", "git", []string{"-C", "/dir", "--no-optional-locks", "-c", "core.quotepath=false",
+			"-c", "color.status=false", "rev-list", "--count", "HEAD..origin/main"}).Return(tc.PushBehindCount, nil)
+		env.On("FileContent", "/dir/.git/config").Return("")
+
+		g := &Git{
+			Scm: Scm{
+				command:     "git",
+				repoRootDir: "/dir",
+				scmDir:      "/dir/.git",
+			},
+			Ref:      "main",
+			Upstream: "origin/main",
+		}
+
+		props := properties.Map{
+			FetchPushStatus: true,
+		}
+
+		g.Init(props, env)
+
+		g.configOnce = sync.Once{}
+		g.configOnce.Do(func() {
+			if len(tc.Config) > 0 {
+				g.config, g.configErr = ini.Load([]byte(tc.Config))
+				return
+			}
+
+			g.configErr = errors.New("no config")
+		})
+
+		g.setPushStatus()
+
+		assert.Equal(t, tc.ExpectedPushAhead, g.PushAhead, tc.Case)
+		assert.Equal(t, tc.ExpectedPushBehind, g.PushBehind, tc.Case)
+	}
+}
