@@ -5,18 +5,16 @@ import (
 	"net"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
-	mock2 "github.com/stretchr/testify/mock"
-)
-
-const (
-	IPIFYAPIURL = "https://api.ipify.org"
+	testify_ "github.com/stretchr/testify/mock"
 )
 
 type mockedipAPI struct {
-	mock2.Mock
+	testify_.Mock
 }
 
 func (s *mockedipAPI) Get() (*ipData, error) {
@@ -57,15 +55,21 @@ func TestIpifySegment(t *testing.T) {
 
 		ipify := &IPify{
 			api: api,
+			Base: Base{
+				env:   &mock.Environment{},
+				props: properties.Map{},
+			},
 		}
 
 		enabled := ipify.Enabled()
 		assert.Equal(t, tc.ExpectedEnabled, enabled, tc.Case)
 
+		cache.DeleteAll(cache.Device)
+
 		if !enabled {
 			continue
 		}
 
-		assert.Equal(t, tc.ExpectedString, renderTemplate(&mock.MockedEnvironment{}, ipify.Template(), ipify), tc.Case)
+		assert.Equal(t, tc.ExpectedString, renderTemplate(&mock.Environment{}, ipify.Template(), ipify), tc.Case)
 	}
 }
