@@ -1,7 +1,7 @@
 package segments
 
 type Svelte struct {
-	language
+	Language
 }
 
 func (s *Svelte) Template() string {
@@ -9,11 +9,7 @@ func (s *Svelte) Template() string {
 }
 
 func (s *Svelte) Enabled() bool {
-	if !s.hasNodePackage("svelte") {
-		return false
-	}
-
-	s.extensions = []string{"package.json"}
+	s.extensions = []string{"svelte.config.js"}
 	s.commands = []*cmd{
 		{
 			regex:      `(?:(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+))))`,
@@ -22,7 +18,7 @@ func (s *Svelte) Enabled() bool {
 	}
 	s.versionURLTemplate = "https://github.com/sveltejs/svelte/releases/tag/svelte%40{{.Full}}"
 
-	return s.language.Enabled()
+	return s.Language.Enabled()
 }
 
 func (s *Svelte) getVersion() (string, error) {
