@@ -12,8 +12,12 @@ import (
 	"github.com/hashicorp/hcl/v2/hclparse"
 )
 
+const (
+	Command properties.Property = "command"
+)
+
 type Terraform struct {
-	base
+	Base
 
 	TerraformBlock
 	WorkspaceName string
@@ -32,7 +36,7 @@ type TerraformBlock struct {
 }
 
 func (tf *Terraform) Enabled() bool {
-	cmd := "terraform"
+	cmd := tf.props.GetString(Command, "terraform")
 	fetchVersion := tf.props.GetBool(properties.FetchVersion, false)
 
 	if !tf.env.HasCommand(cmd) || !tf.inContext(fetchVersion) {
