@@ -24,6 +24,7 @@ var (
 	shell       string
 	env         runtime.Environment
 	knownFields sync.Map
+	textPool    *generics.Pool[*Text]
 )
 
 func Init(environment runtime.Environment, vars maps.Simple[any], aliases *maps.Config) {
@@ -38,6 +39,10 @@ func Init(environment runtime.Environment, vars maps.Simple[any], aliases *maps.
 		}
 	})
 
+	textPool = generics.NewPool(func() *Text {
+		return &Text{}
+	})
+
 	if Cache != nil {
 		return
 	}
